.. module:: pymeasure.instruments.philips

#######
Philips
#######

This section contains specific documentation on the Philips instruments that are implemented.
If you are interested in an instrument not included, please consider :doc:`adding the instrument </dev/adding_instruments/index>`.`.

.. toctree::
   :maxdepth: 2

   PM6669
